pub struct ChaffStreamArgs { /* private fields */ }Implementations
Sourceimpl ChaffStreamArgs
impl ChaffStreamArgs
Sourcepub fn with_length(output_length: usize) -> Self
pub fn with_length(output_length: usize) -> Self
The output_length parameter controls the size of the hypothetical chaff input file.
In other words, the length of the stream is the length of the headers plus output_length.
pub fn set_chunk_size( &mut self, chunk_size: usize, ) -> Result<(), ChunkSizeTooSmallError>