pub struct DecryptArgs { /* private fields */ }Expand description
builder for arguments to Decrypt::new with default values, can be constructed with DecryptArgs::default
Implementations
Sourceimpl DecryptArgs
impl DecryptArgs
Sourcepub fn set_bytes_per_poll(&mut self, bytes_per_poll: NonZeroUsize)
pub fn set_bytes_per_poll(&mut self, bytes_per_poll: NonZeroUsize)
sets the maximum number of bytes to decrypt before yielding to the executor