pub struct EncryptArgs { /* private fields */ }Expand description
builder for arguments to Encrypt::new with default values, can be constructed with EncryptArgs::default
Implementations
Sourceimpl EncryptArgs
impl EncryptArgs
Sourcepub fn set_bytes_per_poll(&mut self, bytes_per_poll: NonZeroUsize)
pub fn set_bytes_per_poll(&mut self, bytes_per_poll: NonZeroUsize)
sets the maximum number of bytes to encrypt before yielding to the executor